TouchPoint class

Represents a touch point with its position and animation state

Constructors

TouchPoint({required int pointerId, required Offset position, double animationValue = 1.0, Color? color})

Properties

animationValue double
Animation value (0.0 to 1.0) for blob expansion
final
color Color?
Optional custom color for this touch point
final
hashCode int
The hash code for this object.
no setterinherited
pointerId int
Unique pointer ID
final
position Offset
Position of the touch point
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? pointerId, Offset? position, double? animationValue, Color? color}) TouchPoint
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited