PointerEventHandler class

Tracks pointer positions for DotGridWidget mesh effects.

Constructors

PointerEventHandler({required void onTouchPointsChanged(List<TouchPointData>)})

Properties

hashCode int
The hash code for this object.
no setterinherited
onTouchPointsChanged → void Function(List<TouchPointData>)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
getActiveTouchPoints() List<TouchPointData>
getAllTouchPoints() List<TouchPointData>
handlePointerCancel(int pointerId) → void
handlePointerDown(int pointerId, Offset localPosition, {bool isHover = false, Color? color}) → void
handlePointerMove(int pointerId, Offset localPosition) → void
handlePointerUp(int pointerId) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeTouchPoint(int pointerId) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited