TouchPointData class

Data for one tracked pointer (local coordinates).

Constructors

TouchPointData({required int pointerId, required Offset position, required DateTime timestamp, bool isActive = true, bool isHover = false, Color? color})

Properties

color Color?
final
hashCode int
The hash code for this object.
no setterinherited
isActive bool
final
isHover bool
final
pointerId int
final
position Offset
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
final

Methods

copyWith({int? pointerId, Offset? position, DateTime? timestamp, bool? isActive, bool? isHover, Color? color}) TouchPointData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited