TermosTapTarget class
Tap target with dot_grid mesh gradient feedback instead of Material ripple.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- TermosTapTarget
Constructors
- TermosTapTarget({Key? key, required Widget child, VoidCallback? onTap, BorderRadius? borderRadius, bool enabled = true, DotGridController? controller, Color? primaryColor, double? blobRadius, Color? idleMeshColor, double? dotSize, double? gridSpacing, bool shrinkWrapWidth = false})
-
const
Properties
- blobRadius → double?
-
final
- borderRadius → BorderRadius?
-
final
- child → Widget
-
final
- controller → DotGridController?
-
final
- dotSize → double?
-
final
- enabled → bool
-
final
- gridSpacing → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- idleMeshColor → Color?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onTap → VoidCallback?
-
final
- primaryColor → Color?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shrinkWrapWidth → bool
-
When true, width follows child instead of expanding to the incoming max width.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< TermosTapTarget> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited