TermosButtonEffects class

Button card background blend and border (per theme).

Constructors

TermosButtonEffects({double cardBlendLight = 0.4, double cardBlendDark = 0.6, double borderHoverMix = 0.2, double borderPressedMix = 0.8, double borderHoveredMix = 0.5, double contentMutedAlpha = 0.5})
const

Properties

borderHoveredMix double
final
borderHoverMix double
final
borderPressedMix double
final
cardBlendDark double
final
cardBlendLight double
Color.lerp(background, card, this) for button fill.
final
contentMutedAlpha double
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({double? cardBlendLight, double? cardBlendDark, double? borderHoverMix, double? borderPressedMix, double? borderHoveredMix, double? contentMutedAlpha}) TermosButtonEffects
lerp(TermosButtonEffects other, double t) TermosButtonEffects
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override