TermosCrtEffects class

CRT outer bezel / shadows (per theme).

Constructors

TermosCrtEffects({double outerBorderAlphaLight = 0.08, double outerBorderAlphaDark = 0.06, double shadowLightAlpha = 0.08, double shadowDarkAlpha = 0.5, double shadowBlurLight = 8, double shadowBlurDark = 20, double shadowSpreadLight = 0, double shadowSpreadDark = 2, double vignetteGradientRadius = 1.5, double vignetteGradientStopTransparent = 0.5, double vignetteGradientStopDark = 1.0})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
outerBorderAlphaDark double
final
outerBorderAlphaLight double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadowBlurDark double
final
shadowBlurLight double
final
shadowDarkAlpha double
final
shadowLightAlpha double
final
shadowSpreadDark double
final
shadowSpreadLight double
final
vignetteGradientRadius double
final
vignetteGradientStopDark double
final
vignetteGradientStopTransparent double
final

Methods

copyWith({double? outerBorderAlphaLight, double? outerBorderAlphaDark, double? shadowLightAlpha, double? shadowDarkAlpha, double? shadowBlurLight, double? shadowBlurDark, double? shadowSpreadLight, double? shadowSpreadDark, double? vignetteGradientRadius, double? vignetteGradientStopTransparent, double? vignetteGradientStopDark}) TermosCrtEffects
lerp(TermosCrtEffects other, double t) TermosCrtEffects
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override