TermosNavBarEffects class

Nav bar dot grid / starfield / glow shell (per theme).

Constructors

TermosNavBarEffects({double glowColorMixWithWhite = 0.5, double dotGridPrimaryMixWithWhite = 0.5, double dotGridPrimaryAlphaLight = 0.5, double dotGridPrimaryAlphaDark = 1, double selectionAlphaLight = 0.35, double selectionAlphaDark = 0.25, double starfieldIntensityLight = 1.5, double starfieldIntensityDark = 1, double glowShellBaseOpacityLight = 0.1, double glowShellBaseOpacityDark = 0.05, int dotGridExpansionMs = 100, int dotGridDecayMs = 280})
const

Properties

dotGridDecayMs int
final
dotGridExpansionMs int
final
dotGridPrimaryAlphaDark double
final
dotGridPrimaryAlphaLight double
final
dotGridPrimaryMixWithWhite double
final
glowColorMixWithWhite double
Color.lerp(tabColor, white, this) for top glow color in light mode.
final
glowShellBaseOpacityDark double
final
glowShellBaseOpacityLight double
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectionAlphaDark double
final
selectionAlphaLight double
final
starfieldIntensityDark double
final
starfieldIntensityLight double
final

Methods

copyWith({double? glowColorMixWithWhite, double? dotGridPrimaryMixWithWhite, double? dotGridPrimaryAlphaLight, double? dotGridPrimaryAlphaDark, double? selectionAlphaLight, double? selectionAlphaDark, double? starfieldIntensityLight, double? starfieldIntensityDark, double? glowShellBaseOpacityLight, double? glowShellBaseOpacityDark, int? dotGridExpansionMs, int? dotGridDecayMs}) TermosNavBarEffects
lerp(TermosNavBarEffects other, double t) TermosNavBarEffects
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override