TermosSegmentedEffects class

Segmented selector top glow (per theme).

Constructors

TermosSegmentedEffects({double glowColorMixWithWhite = 0.5, double glowBaseOpacityLight = 0.15, double glowBaseOpacityDark = 0.05})
const

Properties

glowBaseOpacityDark double
final
glowBaseOpacityLight double
final
glowColorMixWithWhite double
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({double? glowColorMixWithWhite, double? glowBaseOpacityLight, double? glowBaseOpacityDark}) TermosSegmentedEffects
lerp(TermosSegmentedEffects other, double t) TermosSegmentedEffects
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override