TermosStarfieldConfig class

ReactiveStarfieldPainter and related effect defaults (per theme).

Constructors

TermosStarfieldConfig({double glowPositionButton = 0.5, double glowPositionBackButton = 0.5, double? glowRadiusFraction, double intensityButtonLight = 1.8, double intensityButtonDark = 1.5, double intensityButtonDisabledBlend = 0.5, double intensityBackButtonLight = 2, double intensityBackButtonDark = 1.5})
const

Properties

glowPositionBackButton double
final
glowPositionButton double
Horizontal glow center for button starfield (0–1).
final
glowRadiusFraction double?
final
hashCode int
The hash code for this object.
no setteroverride
intensityBackButtonDark double
final
intensityBackButtonLight double
final
intensityButtonDark double
final
intensityButtonDisabledBlend double
Multiplier on disabled state when lerping starfield intensity.
final
intensityButtonLight double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({double? glowPositionButton, double? glowPositionBackButton, double? glowRadiusFraction, double? intensityButtonLight, double? intensityButtonDark, double? intensityButtonDisabledBlend, double? intensityBackButtonLight, double? intensityBackButtonDark, bool clearGlowRadiusFraction = false}) TermosStarfieldConfig
lerp(TermosStarfieldConfig other, double t) TermosStarfieldConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override