TermosTimePickerEffects class

Time picker drum styling (per theme).

Constructors

TermosTimePickerEffects({double scanlineOpacityLight = 0.015, double scanlineOpacityDark = 0.03, double selectionBandBgAlphaLight = 0.03, double selectionBandBgAlphaDark = 0.04, double selectionBandGlowAlphaLight = 0.2, double selectionBandGlowAlphaDark = 0.3, double colonPulseOpacityMin = 0.4, double colonPulseOpacityMax = 1.0, double colonFontSize = 26, double wheelFontSize = 24})
const

Properties

colonFontSize double
final
colonPulseOpacityMax double
final
colonPulseOpacityMin double
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scanlineOpacityDark double
final
scanlineOpacityLight double
final
selectionBandBgAlphaDark double
final
selectionBandBgAlphaLight double
final
selectionBandGlowAlphaDark double
final
selectionBandGlowAlphaLight double
final
wheelFontSize double
final

Methods

copyWith({double? scanlineOpacityLight, double? scanlineOpacityDark, double? selectionBandBgAlphaLight, double? selectionBandBgAlphaDark, double? selectionBandGlowAlphaLight, double? selectionBandGlowAlphaDark, double? colonPulseOpacityMin, double? colonPulseOpacityMax, double? colonFontSize, double? wheelFontSize}) TermosTimePickerEffects
lerp(TermosTimePickerEffects other, double t) TermosTimePickerEffects
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override