TermosMetrics class
Layout tokens: radii, paddings, sizes — set once per theme, applied by Termos widgets.
Constructors
- TermosMetrics({double borderRadius = 8, double buttonHeight = 44, double buttonIconSize = 20, double buttonIconSpacing = 8, double buttonLoadingSpinnerSize = 16, double buttonLoadingSpinnerSlotSize = 20, int buttonDisabledTransitionMs = 200, double buttonHorizontalPadding = 16, double backButtonDefaultSize = 54, EdgeInsets backButtonPadding = const EdgeInsets.fromLTRB(12, 18, 12, 18), double backButtonBackgroundBlend = 0.5, String backButtonGlyph = '<-', double tapTargetDefaultBorderRadius = 8, double segmentedHeight = 44, int segmentedGlowAnimationMs = 320, double timePickerWheelWidth = 72, double timePickerItemExtent = 40, int timePickerVisibleItems = 3, int timePickerPulseAnimationMs = 1200, double crtScanlineOpacity = 0.06, double crtVignetteStrength = 0.5, double crtOuterBorderWidth = 1, double glowTopBorderStrokeWidth = 2})
-
const
Properties
- backButtonBackgroundBlend → double
-
Color.lerp(background, card, this) for back button fill.
final
- backButtonDefaultSize → double
-
final
- backButtonGlyph → String
-
Shown when TermosBackButton.label is null.
final
- backButtonPadding → EdgeInsets
-
final
- borderRadius → double
-
final
-
no setter
-
final
-
final
-
final
-
final
-
final
-
final
-
final
- crtOuterBorderWidth → double
-
final
- crtScanlineOpacity → double
-
final
- crtVignetteStrength → double
-
final
- glowTopBorderStrokeWidth → double
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
-
no setter
-
final
-
final
-
final
-
final
-
final
-
final
-
final
-
final
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- segmentedGlowAnimationDuration → Duration
-
no setter
- segmentedGlowAnimationMs → int
-
final
- segmentedHeight → double
-
final
- tapTargetDefaultBorderRadius → double
-
final
- timePickerItemExtent → double
-
final
- timePickerPulseAnimationDuration → Duration
-
no setter
- timePickerPulseAnimationMs → int
-
final
- timePickerVisibleItems → int
-
final
- timePickerWheelWidth → double
-
final
Methods
-
copyWith(
{double? borderRadius, double? buttonHeight, double? buttonIconSize, double? buttonIconSpacing, double? buttonLoadingSpinnerSize, double? buttonLoadingSpinnerSlotSize, int? buttonDisabledTransitionMs, double? buttonHorizontalPadding, double? backButtonDefaultSize, EdgeInsets? backButtonPadding, double? backButtonBackgroundBlend, String? backButtonGlyph, double? tapTargetDefaultBorderRadius, double? segmentedHeight, int? segmentedGlowAnimationMs, double? timePickerWheelWidth, double? timePickerItemExtent, int? timePickerVisibleItems, int? timePickerPulseAnimationMs, double? crtScanlineOpacity, double? crtVignetteStrength, double? crtOuterBorderWidth, double? glowTopBorderStrokeWidth}) → TermosMetrics -
lerp(
TermosMetrics other, double t) → TermosMetrics -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- standard → const TermosMetrics