LoaderRandomConfig class

Configuration for TermosCometCircularProgress.

Constructors

LoaderRandomConfig({required int objectCount, required double dotSize, required int trailLength, required double trailSpacing, required double perturbAmplitude, required double perturbFrequency, required double velocityMultiplier, required double glowBlurRadius, required double glowOpacity, required double reactiveRadius, required double orbitEccentricity, required double perihelionGlow, required double tailCurvature, required double velocityWarp, required double precessionRate, required double orbitalInclination, required int intensityTransitionDurationMs, required Color color})
const

Properties

color Color
final
dotSize double
final
glowBlurRadius double
final
glowOpacity double
final
hashCode int
The hash code for this object.
no setterinherited
intensityTransitionDurationMs int
final
objectCount int
final
orbitalInclination double
final
orbitEccentricity double
final
perihelionGlow double
final
perturbAmplitude double
final
perturbFrequency double
final
precessionRate double
final
reactiveRadius double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tailCurvature double
final
trailLength int
final
trailSpacing double
final
velocityMultiplier double
final
velocityWarp double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited