TermosButton class

Primary CTA with dot grid mesh, starfield background, and optional typing loading animation.

Inheritance

Constructors

TermosButton({Key? key, required Text label, VoidCallback? onTap, Widget? icon, bool enabled = true, bool isLoading = false, String? loadingLabel, bool typingLoadingTransition = false, bool savedState = false, bool allowTapWhenSaved = false, String? savedLabel, Widget? savedIcon, double? height, double? width, bool expandWidth = true, Color? color, BorderRadius? borderRadius})
const

Properties

allowTapWhenSaved bool
final
borderRadius BorderRadius?
final
color Color?
final
enabled bool
final
expandWidth bool
When true (default), the button fills available horizontal space. When false, width follows label + icon (unless width is set).
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
icon Widget?
final
isLoading bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label Text
final
loadingLabel String?
final
onTap VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
savedIcon Widget?
final
savedLabel String?
final
savedState bool
final
typingLoadingTransition bool
final
width double?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<TermosButton>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited