DotGridPainter class
A custom painter that renders a grid of dots with mesh gradient effects.
- Inheritance
-
- Object
- Listenable
- CustomPainter
- DotGridPainter
Constructors
-
DotGridPainter({required double dotSize, required double gridSpacing, required Color primaryColor, required Color backgroundColor, required Float32List pointsBuffer, List<
int> dotPattern = const [1, 5], List<TouchPoint> touchPoints = const [], List<SelectionPoint> selectionPoints = const [], double blobRadius = 100.0, List<Color> gradientColors = const [], double hoverOpacity = 1.0, Map<int, bool> hoverStates = const {}, Offset gridOffset = Offset.zero})
Properties
- backgroundColor → Color
-
Background color for inactive dots
final
- blobRadius → double
-
Maximum radius of the blob effect
final
-
dotPattern
→ List<
int> -
Pattern: number of colored dots, then number of background dots
For example:
1, 5means 1 colored dot, 5 background dots, repeatfinal - dotSize → double
-
Size of each dot in pixels
final
-
gradientColors
→ List<
Color> -
List of colors for mesh gradient (interpolated based on distance)
final
- gridOffset → Offset
-
Offset of this widget relative to its DotGridGroup origin.
Dots are shifted so the grid aligns across the group. Touch/selection
are in canvas (same as dot positions).
final
- gridSpacing → double
-
Spacing between dots in pixels
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hoverOpacity → double
-
Opacity multiplier for hover effects (0.0 to 1.0)
final
-
hoverStates
→ Map<
int, bool> -
Map of pointer IDs to whether they are hover events
final
- pointsBuffer → Float32List
-
Pre-allocated buffer for dot coordinates (x, y pairs).
Created once in the widget state, reused across paints.
final
- primaryColor → Color
-
Primary color for active dots (colored dots)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
selectionPoints
→ List<
SelectionPoint> -
Static selection points (e.g. selected tab) - drawn as filled mesh gradient
final
- semanticsBuilder → SemanticsBuilderCallback?
-
Returns a function that builds semantic information for the picture drawn
by this painter.
no setterinherited
-
touchPoints
→ List<
TouchPoint> -
List of active touch points with their current animation values
final
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be notified when it is time to repaint.
inherited
-
hitTest(
Offset position) → bool? -
Called whenever a hit test is being performed on an object that is using
this custom paint delegate.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
Canvas canvas, Size size) → void -
Called whenever the object needs to paint. The given Canvas has its
coordinate space configured such that the origin is at the top left of the
box. The area of the box is the size of the
sizeargument.override -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies when it is time to repaint.
inherited
-
shouldRebuildSemantics(
covariant CustomPainter oldDelegate) → bool -
Called whenever a new instance of the custom painter delegate class is
provided to the RenderCustomPaint object, or any time that a new
CustomPaint object is created with a new instance of the custom painter
delegate class (which amounts to the same thing, because the latter is
implemented in terms of the former).
inherited
-
shouldRepaint(
covariant DotGridPainter oldDelegate) → bool -
Called whenever a new instance of the custom painter delegate class is
provided to the RenderCustomPaint object, or any time that a new
CustomPaint object is created with a new instance of the custom painter
delegate class (which amounts to the same thing, because the latter is
implemented in terms of the former).
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited