DotGridWidget class
Layered dot mesh with tap ripples (filled blob then expanding ring) and optional hover.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- DotGridWidget
Constructors
-
DotGridWidget({Key? key, required Widget child, DotGridController? controller, double dotSize = 4.0, double gridSpacing = 6.0, Color primaryColor = Colors.blue, Color backgroundColor = Colors.white, List<
int> dotPattern = const [1, 5], Duration expansionDuration = const Duration(milliseconds: 200), Duration decayDuration = const Duration(milliseconds: 400), double blobRadius = 100.0, List<Color> gradientColors = const [], double hoverOpacity = 1.0, bool enableHoverEffect = true, bool enabled = true, bool interactiveMesh = true}) -
const
Properties
- backgroundColor → Color
-
final
- blobRadius → double
-
final
- child → Widget
-
final
- controller → DotGridController?
-
final
- decayDuration → Duration
-
final
-
dotPattern
→ List<
int> -
final
- dotSize → double
-
final
- enabled → bool
-
final
- enableHoverEffect → bool
-
final
- expansionDuration → Duration
-
final
-
gradientColors
→ List<
Color> -
final
- gridSpacing → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hoverOpacity → double
-
final
- interactiveMesh → bool
-
Mesh response to pointers and DotGridController.triggerAt. Grid still paints when false.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- primaryColor → Color
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< DotGridWidget> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited