MeshGradientAnimation class
Drives expansion / decay animation for mesh tap effects (filled blob then outward ring).
Constructors
- MeshGradientAnimation({required TickerProvider vsync, required void onAnimationUpdate(), Duration expansionDuration = const Duration(milliseconds: 200), Duration decayDuration = const Duration(milliseconds: 400), Curve expansionCurve = Curves.easeOut, Curve decayCurve = Curves.easeIn})
Properties
- decayCurve → Curve
-
final
- decayDuration → Duration
-
final
- expansionCurve → Curve
-
final
- expansionDuration → Duration
-
final
- hasActiveAnimations → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- onAnimationUpdate → void Function()
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- vsync → TickerProvider
-
final
Methods
-
dispose(
) → void -
getAnimatedTouchPoints(
List< TouchPointData> touchPointData) → List<TouchPoint> -
getAnimationValue(
int pointerId) → double -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startDecay(
int pointerId) → void -
startExpansion(
int pointerId) → void -
toString(
) → String -
A string representation of this object.
inherited
-
updateDecayDuration(
int pointerId, Duration duration) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited