TermosColors class
Semantic color tokens for Termos widgets (brightness-aware).
Constructors
- TermosColors({required Color primary, required Color background, required Color surface, required Color card, required Color border, required Color textPrimary, required Color textSecondary, required Color textMuted, required Color success, required Color warning, required Color error, required Color info, required Color dotGridButtonBorder, required Color dotGridIdleMesh, required Color syntaxOperator})
-
const
Properties
- background → Color
-
final
- border → Color
-
final
- card → Color
-
final
- dotGridButtonBorder → Color
-
Border for dot-grid buttons (back, action, etc.).
final
- dotGridIdleMesh → Color
-
Idle mesh/background for dot grid.
final
- error → Color
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- info → Color
-
final
- primary → Color
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → Color
-
final
- surface → Color
-
final
- syntaxOperator → Color
-
Accent for operators in command syntax (optional use).
final
- textMuted → Color
-
final
- textPrimary → Color
-
final
- textSecondary → Color
-
final
- warning → Color
-
final
Methods
-
copyWith(
{Color? primary, Color? background, Color? surface, Color? card, Color? border, Color? textPrimary, Color? textSecondary, Color? textMuted, Color? success, Color? warning, Color? error, Color? info, Color? dotGridButtonBorder, Color? dotGridIdleMesh, Color? syntaxOperator}) → TermosColors -
lerp(
TermosColors other, double t) → TermosColors -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
forBrightness(
Brightness brightness) → TermosColors
Constants
- dark → const TermosColors
- light → const TermosColors