Default font family names used by TermosTextStyles.fromColors.
The library does not bundle or fetch these fonts. The consuming app must
make them available — either via google_fonts, bundled assets, or system
fonts. Override individual styles with TermosTextStyles constructor if you
use different family names.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited