TermosThemeData class
Central theme for all Termos widgets: layout, dot grid, colors, typography, effects.
Can be provided via TermosTheme (InheritedWidget) or registered as a ThemeExtension on Material's ThemeData. TermosTheme.of checks both.
- Inheritance
-
- Object
- ThemeExtension<
TermosThemeData> - TermosThemeData
Constructors
- TermosThemeData({required TermosColors colors, required DotGridConfig dotGrid, required TermosTextStyles textStyles, TermosMetrics metrics = TermosMetrics.standard, TermosStarfieldConfig starfield = const TermosStarfieldConfig(), TermosSegmentedEffects segmented = const TermosSegmentedEffects(), TermosButtonEffects button = const TermosButtonEffects(), TermosCrtEffects crt = const TermosCrtEffects(), TermosTimePickerEffects timePicker = const TermosTimePickerEffects(), bool heavyEffectsEnabled = true})
-
const
- TermosThemeData.dark()
-
factory
- TermosThemeData.fallbackBrightness(Brightness brightness)
-
factory
- TermosThemeData.light()
-
factory
Properties
-
final
- colors → TermosColors
-
final
- crt → TermosCrtEffects
-
final
- dotGrid → DotGridConfig
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- heavyEffectsEnabled → bool
-
When false, dot grid mesh and starfields are skipped (Material fallbacks).
final
- metrics → TermosMetrics
-
final
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- segmented → TermosSegmentedEffects
-
final
- starfield → TermosStarfieldConfig
-
final
- textStyles → TermosTextStyles
-
final
- timePicker → TermosTimePickerEffects
-
final
- type → Object
-
The extension's type.
no setterinherited
Methods
-
copyWith(
{TermosColors? colors, DotGridConfig? dotGrid, TermosTextStyles? textStyles, TermosMetrics? metrics, TermosStarfieldConfig? starfield, TermosSegmentedEffects? segmented, TermosButtonEffects? button, TermosCrtEffects? crt, TermosTimePickerEffects? timePicker, bool? heavyEffectsEnabled}) → TermosThemeData -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant TermosThemeData? other, double t) → TermosThemeData -
Linearly interpolate with another ThemeExtension object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override