TermosSwitch class

Particle-style ON/OFF switch with dot field and edge glow (falls back to simple track when heavy effects off).

Inheritance

Constructors

TermosSwitch({Key? key, required bool value, ValueChanged<bool>? onChanged, double blobRadius = 21.5, double edgeSharpness = 5, double glowIntensity = 0.5, double? dotSize, double? gridSpacing, double blobInset = 8, double onAlpha = 1, double offAlpha = 0.23, double idleAlpha = 0.05, double sweepWeight = 0, double blobWeight = 1, double trackWidth = 82, double trackHeight = 33.5, double? trackRadius, double borderWidth = 1, double glowStrokeWidth = 1})
const

Properties

blobInset double
final
blobRadius double
final
blobWeight double
final
borderWidth double
final
dotSize double?
final
edgeSharpness double
final
glowIntensity double
final
glowStrokeWidth double
final
gridSpacing double?
final
hashCode int
The hash code for this object.
no setterinherited
idleAlpha double
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
offAlpha double
final
onAlpha double
final
onChanged ValueChanged<bool>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sweepWeight double
final
trackHeight double
final
trackRadius double?
When null, uses TermosThemeData.metrics.borderRadius.
final
trackWidth double
final
value bool
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<TermosSwitch>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited